@@ -8,7 +8,8 @@ class DocumentNotFound(Exception):
 
 
 class WordPressReader(object):
-    def __init__(self,
+    def __init__(
+            self,
             host,
             user,
             passwd,
@@ -58,6 +59,42 @@ class WordPressReader(object):
         self.connection.commit()
         return cursor
 
+    def get_descendants_for_id(self, wp_id):
+        sql = """
+            SELECT
+                parent.id AS parent_id,
+                parent.post_title AS parent_title,
+                child.post_title AS child_title,
+                child.post_name AS child_slug
+            FROM
+                {0}_posts AS parent
+                inner join {0}_posts AS child ON parent.ID = child.post_parent
+                inner join {0}_posts AS super ON super.ID = parent.post_parent
+            WHERE
+                parent.post_parent = %s
+                AND super.post_status = 'publish'
+                AND parent.post_status = 'publish'
+                AND child.post_status = 'publish'
+            ORDER BY
+                parent.menu_order,
+                child.menu_order
+            """.format(self.table_prefix)
+        cursor = self.query(sql, (wp_id,))
+        results = []
+        last_parent_id = None
+        for row in cursor:
+            if last_parent_id != row[0]:
+                parent_document = WordPressParent(
+                    title=row[1],
+                    children=[{'title': row[2], 'slug': row[3]}])
+                results.append(parent_document)
+            else:
+                results[-1].children.append(
+                    {'title': row[2], 'slug': row[3]})
+            last_parent_id = row[0]
+
+        return results
+
     def get_document_by_slug(self, wp_slug):
         return WordPressDocument.from_wp_slug(
             self,
